@@ -464,8 +464,8 @@ class EPN(models.Model):
     objects = EPNManager()
 
     def __unicode__(self):
-        return u'EPN "{0}" from "{1}" (IPN: {2})'.format(
-            self.epn, self.company_description, self.ipn_code)
+        return u'EPN "{0}" - {1}'.format(
+            self.epn, self.description)
 
     def save(self, *args, **kwargs):
         if self.ipn_id is not None:
